Module reader

Module reader 

Read-only SQLite access to an opencode.db.

We always open the database with SQLITE_OPEN_READ_ONLY (and SQLITE_OPEN_NO_MUTEX) so we never interfere with a live opencode process writing to the same file. SQLite WAL mode allows concurrent readers and a single writer — readers observe a consistent snapshot as of the transaction start.

Structs

DbReader
Thin wrapper around a rusqlite connection opened read-only against an opencode database.